@@ -3,7 +3,7 @@ from typing import Dict, Iterator, Union
 
 if sys.version_info >= (3, 11):  # pragma: no cover
     from typing import Self
-else:
+else:  # pragma: no cover
     from typing_extensions import Self
 
 from jellyfin_apiclient_python.api import API
@@ -37,6 +37,12 @@ class ApiResponse:
         yield from [Item(i) for i in self.value["Items"]]
 
     def __getitem__(self, key) -> Item:
+        if isinstance(key, slice):
+            items = range(
+                key.start or 0,
+                key.stop or len(self.value["Items"]),
+                key.step or 1)
+            return [Item(self.value["Items"][k]) for k in items]
         return Item(self.value["Items"][key])
 
     def _raw_value(self):
@@ -49,7 +55,8 @@ class ApiResponse:
 class WrappedAPI(API):
     def _get(self, handler, params=None):
         resp = super()._get(handler, params=params)
-        if set(("Items", "TotalRecordCount")) <= set(resp.keys()):
-            return ApiResponse(resp)
+        if isinstance(resp, dict):
+            if set(("Items", "TotalRecordCount")) <= set(resp.keys()):
+                return ApiResponse(resp)
         return resp
 
